@@ -220,7 +220,7 @@ def test_misspelling_pings():
     assert set(["MISSPELLED_PING"]) == set(v.check_name for v in nits)
 
 
-def test_yaml_lint():
+def test_yaml_lint(capsys):
     """Tests yamllint on files with nits."""
     file_paths = [ROOT / "data" / "core.yaml", ROOT / "data" / "yaml_nits.yamlx"]
 
@@ -230,6 +230,14 @@ def test_yaml_lint():
     # The second rule is empty because it's a syntax error.
     assert set(["indentation", None, "trailing-spaces"]) == set(v.rule for v in nits)
 
+    captured = capsys.readouterr()
+    lines = captured.out.split("\n")
+    for line in lines:
+        if line.strip() == "":
+            continue
+        assert "yaml_nits.yamlx" in line
+        assert "core.yaml" not in line
+
 
 def test_user_lifetime_expiration():
     """Test that expiring 'user' lifetime metrics generate a warning."""
